<script setup>
import { getCurrentInstance, ref, computed, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postBlob } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import EditView from './edit.vue'
import { formatMessage } from '@/utils/localeUtils.js';
import useTableSearch from '@/utils/tableUtils.jsx';
const context = getCurrentInstance()?.appContext.config.globalProperties;

const router = useRouter();

const TABLE_KEY = 'table-waitPakinLog';
let currentPage = 1;
let pageSize = 10;
const searchInput = ref("")
const searchParam = ref({
  orderNo: null,
  barcode: null,
  matnr: null,
  batch: null,
})
const editChild = ref(null)

const state = reactive({
  selectedRowKeys: [],
  loading: false,
});

let tableData = ref([]);
getPage();

const {
  getColumnSearchProps,
  handleResizeColumn,
} = useTableSearch();

const columns = [
  {
    title: formatMessage('db.man_wait_pakin_log.order_id', '订单ID'),
    dataIndex: 'orderId$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('orderId$'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.order_no', '订单编号'),
    dataIndex: 'orderNo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('orderNo'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.anfme', '组托数量'),
    dataIndex: 'anfme',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('anfme'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.barcode', '托盘码'),
    dataIndex: 'barcode',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('barcode'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.matnr', '商品编号'),
    dataIndex: 'matnr',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('matnr'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.batch', '批号'),
    dataIndex: 'batch',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('batch'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.io_status', '组托状态'),
    dataIndex: 'ioStatus$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('ioStatus$'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.status', '状态'),
    dataIndex: 'status$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('status$'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.create_time', '添加时间'),
    dataIndex: 'createTime$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('createTime$'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.create_by', '添加人员'),
    dataIndex: 'createBy$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('createBy$'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.update_time', '修改时间'),
    dataIndex: 'updateTime$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('updateTime$'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.update_by', '修改人员'),
    dataIndex: 'updateBy$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('updateBy$'),
  },
  {
    title: formatMessage('db.man_wait_pakin_log.memo', '备注'),
    dataIndex: 'memo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('memo'),
  },

  {
    title: formatMessage('common.operation', '操作'),
    name: 'oper',
    dataIndex: 'oper',
    key: 'oper',
    width: 140,
  },
];


const hasSelected = computed(() => state.selectedRowKeys.length > 0);
const start = () => {
  state.loading = true;
  // ajax request after empty completing
  setTimeout(() => {
    state.loading = false;
    state.selectedRowKeys = [];
  }, 1000);
};
const onSelectChange = selectedRowKeys => {
  // console.log('selectedRowKeys changed: ', selectedRowKeys);
  state.selectedRowKeys = selectedRowKeys;
};

function getPage() {
  state.loading = true;
  post('/api/waitPakinLog/page', {
    current: currentPage,
    pageSize: pageSize,
    condition: searchInput.value,
    _param: searchParam.value,
  }).then((resp) => {
    let result = resp.data;
    if (result.code == 200) {
      let data = result.data;
      tableData.value = data;

      state.loading = false;
    } else if (result.code === 401) {
      message.error(result.msg);
      logout()
    } else {
      message.error(result.msg);
    }
  })
}

const handleEdit = (item) => {
  editChild.value.open = true;
  editChild.value.formData = item == null ? editChild.value.initFormData : JSON.parse(JSON.stringify(item));
  editChild.value.isSave = item == null;
}

const handleDel = (rows) => {
  Modal.confirm({
    title: formatMessage('page.delete', '删除'),
    content: formatMessage('page.delete.confirm', '确定删除该项吗？'),
    maskClosable: true,
    onOk: async () => {
      const hide = message.loading(formatMessage('common.loading', '请求中'));
      try {
        post('/api/waitPakinLog/remove/' + rows.map((row) => row.id).join(','), {}).then(resp => {
          let result = resp.data;
          if (result.code === 200) {
            message.success(result.msg);
          } else {
            message.error(result.msg);
          }
          getPage()
          hide()
        })
      } catch (error) {
        message.error(formatMessage('common.fail', '请求失败'));
      }
    },
  });
}

const handleExport = async (intl) => {
  postBlob('/api/waitPakinLog/export', {
    condition: searchInput.value,
    _param: searchParam.value,
  }).then(result => {
    const blob = new Blob([result.data], { type: 'application/vnd.ms-excel' });
    window.location.href = window.URL.createObjectURL(blob);
    return true;
  })
};

const onSearch = () => {
  // console.log('search');
  getPage()
}

const onPageChange = (page, size) => {
  currentPage = page;
  pageSize = size;
  getPage();
}

function handleTableReload(value) {
  getPage()
}

</script>

<script>
export default {
  name: '组托通知历史档'
}
</script>

<template>
  <div>
    <EditView ref="editChild" @tableReload="handleTableReload" />
    <div class="table-header">
      <div>
        <a-input v-model:value="searchParam.orderNo"
          :placeholder="formatMessage('page.waitPakin.orderNo.input', '请输入订单编号')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.barcode"
          :placeholder="formatMessage('page.waitPakin.barcode.input', '请输入托盘码')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.matnr" :placeholder="formatMessage('page.waitPakin.matnr.input', '请输入商品编号')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.batch" :placeholder="formatMessage('page.waitPakin.batch.input', '请输入批号')"
          style="width: 140px;margin-right: 10px;" />

        <a-input-search v-model:value="searchInput" :placeholder="formatMessage('page.input', '请输入')"
          style="width: 200px;" @search="onSearch" />
      </div>
      <div class="table-header-right">
        <!-- <a-button @click="handleEdit(null)" type="primary">{{ formatMessage('page.add', '添加') }}</a-button> -->
        <a-button @click="handleExport">{{ formatMessage('page.export', '导出') }}</a-button>
      </div>
    </div>
    <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
      :data-source="tableData.records" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
      :pagination="{ total: tableData.total, onChange: onPageChange }"
      :scroll="{ y: 768, scrollToFirstRowOnChange: true }" :columns="columns" @resizeColumn="handleResizeColumn"
      :loading="state.loading">
      <template #bodyCell="{ column, text, record }">
        <template v-if="column.dataIndex === 'oper'">
          <div style="display: flex;justify-content: space-evenly;">
            <a-button type="link" primary @click="handleEdit(record)">{{ formatMessage('page.edit', '编辑') }}</a-button>
            <a-button type="link" danger @click="handleDel([record])">{{ formatMessage('page.delete', '删除')
              }}</a-button>
          </div>
        </template>

        <template v-if="column.dataIndex === 'ioStatus$'">
          <a-switch :checked="record.ioStatus == 1" :checked-children="formatMessage('waitPakin.switch.open', '入库中')"
            :un-checked-children="formatMessage('waitPakin.switch.close', '待入库')" :disabled="true" />
        </template>
      </template>
    </a-table>
  </div>
</template>

<style></style>
